﻿"use strict";

function Controller(display, context, canvasXSize, canvasYSize) {
	this.display = display;
	this.view = new View(context, canvasXSize, canvasYSize, this);
	this.gameOver = null;
	this.mouseX = null;
	this.highestScore = 0;
}



Controller.prototype.start = function() {
	this.title = new Title(this.view);
	this.game = null;
	this.view.load();
	this.view.render();
};



Controller.prototype.finishedLoading = function() {
	this.view.render();
};



Controller.prototype.onMouseMove = function(x, y) {
	this.mouseX = x / display.clientWidth * this.view.canvasXSize;
};



Controller.prototype.onMouseDown = function(x, y) {
	var mouseX = x / display.clientWidth * this.view.canvasXSize;
	var mouseY = y / display.clientHeight * this.view.canvasYSize;
	if (this.title !== null) {
		if (this.title.click(mouseX, mouseY)) {
			this.title = null;
			this.game = new Game(this.view, true);
			this.view.render();
			this.startTimer();
		}
	} else if (this.gameOver !== null) {
		if (this.gameOver.click(mouseX, mouseY)) {
			this.gameOver = null;
			this.game = new Game(this.view, false);
			this.view.render();
			this.startTimer();
		}
	}
};



Controller.prototype.startTimer = function() {
	timerObject = this;
	this.intervalID = window.setInterval(timerCallback, 40);
};



Controller.prototype.stopTimer = function() {
	window.clearInterval(this.intervalID);
	this.intervalID = null;
};



var timerObject;

function timerCallback() {
	timerObject.timerCallback();
}



Controller.prototype.timerCallback = function() {
	if (this.game.onTimer(this.mouseX)) {
		if (this.game.score > this.highestScore)
			this.highestScore = this.game.score;
		this.view.score = this.game.score;
		this.view.highestScore = this.highestScore;
		this.game = null;
		this.stopTimer();
		this.gameOver = new GameOver(this.view);
	}
	this.view.render();
};