﻿"use strict";

function Game(view, firstGame) {
	this.view = view;

	this.distance = 0;
	this.distanceT = 0;
	this.score = 0;

	this.playerAngle = 0;
	this.turnAngle = 0;

	this.roadType = 0;
	this.roadOffset = 0;
	this.roadLength = 20;
	this.roadDirection = 0;

	this.view.cameraZ = this.distance;
	this.view.playerX = 0;
	this.view.controlsHelpTimer = 3 * 25;
	this.view.resetRoad();
	if (!firstGame)
		this.view.randomPlayerImage();
}



Game.prototype.generateRoad = function() {
	this.roadType = 1 - this.roadType;
	this.roadOffset = 0;
	this.roadLength = randomBetween(6, 12);
	if (this.roadType === 0)
		this.roadDirection = 0;
	else
		this.roadDirection = randomBetween(0, 1) * 2 - 1;
};



var maxAngle = 20;
var accelerationSensitivity = 0.25;
var corneringSensitivity = 14;
var steeringWheelSpeed = 0.6;

Game.prototype.onTimer = function(mouseX) {
	this.playerAngle -= this.view.roadAngles[0];
	this.view.shakeSteeringWheel = false;
	if (mouseX < this.view.canvasXSize / 2) {
		if (mouseX > this.view.canvasXSize / 2 - 30)
			this.turnAngle -= steeringWheelSpeed / 2;
		else if (mouseX > 30)
			this.turnAngle -= steeringWheelSpeed;
		else
			this.turnAngle -= steeringWheelSpeed * 2;
		if (this.turnAngle < -4) {
			this.turnAngle = -4;
			this.view.shakeSteeringWheel = true;
		}
	} else {
		if (mouseX < this.view.canvasXSize / 2 + 30)
			this.turnAngle += steeringWheelSpeed / 2;
		else if (mouseX < this.view.canvasXSize - 30)
			this.turnAngle += steeringWheelSpeed;
		else
			this.turnAngle += steeringWheelSpeed * 2;
		if (this.turnAngle > 4) {
			this.turnAngle = 4;
			this.view.shakeSteeringWheel = true;
		}
	}
	this.view.steeringWheelAngle = this.turnAngle;
	this.playerAngle += this.turnAngle;
	if (this.playerAngle > maxAngle)
		this.playerAngle = maxAngle;
	else if (this.playerAngle < -maxAngle)
		this.playerAngle = -maxAngle;
	this.view.playerX += this.playerAngle * 0.5 / 14;
	if (this.view.isPlayerOffRoad() || this.view.hasPlayerHitObstacle()) {
		this.view.addPlayerGhost(this.distance);
		return true;
	}

	if (++this.distanceT == 4) {
		this.distance++;
		this.distanceT = 0;
		if (this.distance % 5 === 0)
			this.score++;
		var nextRoadAngle;
		if (++this.roadOffset === this.roadLength)
			this.generateRoad();
		this.view.nextRoad(this.roadDirection);
		var probabilityMax;
		if (this.distance > 40)
			probabilityMax = 4;
		else if (this.distance > 10)
			probabilityMax = 5;
		else if (this.score > 5)
			probabilityMax = 6;
		else
			probabilityMax = 10;
		if (randomBelow(probabilityMax) === 0) {
			this.view.createObstacle();
		}
	}

	this.view.cameraZ = this.distance;
	this.view.score = this.score;

	return false;
};